<?php

require 'vendor/autoload.php';

use OpenCloud\Rackspace;

$options  = include 'options.php';
$required = array('username', 'apiKey', 'container');

foreach ($required as $key) { 
	if (empty($options[$key])) { 
		throw new Exception(sprintf('%s option is required', $key));
	}
}

$endpoint = ($options['endpoint'] == 'US') 
	? Rackspace::US_IDENTITY_ENDPOINT 
	: Rackspace::UK_IDENTITY_ENDPOINT;

$client = new Rackspace($endpoint, array(
	'username' => $options['username'],
	'apiKey'   => $options['apiKey']
));

# Step 1: Create container
$objectService = $client->objectStoreService('cloudFiles', $options['region']);
$container = $objectService->createContainer($options['container']);

if ($container == false) {
	$container = $objectService->getContainer($options['container']);
}

# Step 2: Enable CDN and static website
$path = __DIR__ . '/../' . $options['localDir'];

if (!file_exists("$path/index.html")) {
	throw new Exception(sprintf("%s/index.html does not exist", $path));
}

$container->uploadDirectory($path);
$container->setStaticIndexPage('index.html');

if (file_exists("$path/error.html")) {
	$container->setStaticErrorPage('error.html');
}
$container->enableCdn();

# Step 3: Update DNS
if ($options['changeDNS'] == true) {
	$dnsService = $client->dnsService();

	// Find the Domain ID
	$domains = $dnsService->domainList();
	foreach ($domains as $domain) {
		if ($domain->name == $options['domain']) {
			$domainId = $domain->id;
		}
	}

	if (!isset($domainId)) {
		throw new Exception(sprintf('%s could not be found in our DNS service', $options['domain']));
	}

	$domain = $dnsService->domain($domainId);

	// Create CNAME record
	$record = $domain->record();
	$record->name = $options['record'];
	$record->data = $container->getCdn()->getCdnUri();
	$record->type = 'CNAME';
	$record->create();
}